ShellHost

Trait ShellHost 

pub trait ShellHost: Send + Sync { }
Engine-side shell host marker.

Implemented by crates/tui/src/tools/shell.rs’s ShellManager (an empty impl ShellHost for ShellManager block). Existing call sites that need to actually invoke shell methods continue to go through the concrete SharedShellManager (e.g. via ToolContext).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors